fisx: Member List

fisx

fisx::SimpleIni Member List

This is the complete list of members for fisx::SimpleIni, including all inherited members.

getSections() | fisx::SimpleIni |
getSubsections(const std::string &parent, std::vector< std::string > &destination, const bool &caseSensitive=true) | fisx::SimpleIni |
parseStringAsMultipleValues(const std::string &keyContent, std::vector< T > &destination, const T &defaultValue, const char &separator=',') (defined in fisx::SimpleIni) | fisx::SimpleIni | inlinestatic
parseStringAsSingleValue(const std::string &keyContent, T &destination, const T &defaultValue) | fisx::SimpleIni | inlinestatic
readFileName(std::string fileName) (defined in fisx::SimpleIni) | fisx::SimpleIni |
readSection(const std::string &section, const bool &caseSensitive=true) | fisx::SimpleIni |
SimpleIni() (defined in fisx::SimpleIni) | fisx::SimpleIni |
SimpleIni(std::string fileName) (defined in fisx::SimpleIni) | fisx::SimpleIni |
startsWith(const std::string &stringToCheck, const std::string &testString) | fisx::SimpleIni | inlinestatic
stringConverter(const std::string &str, T &number) (defined in fisx::SimpleIni) | fisx::SimpleIni | inlinestatic
toLower(std::string &s, const std::locale &loc=std::locale()) | fisx::SimpleIni | inlinestatic
toUpper(std::string &s, const std::locale &loc=std::locale()) | fisx::SimpleIni | inlinestatic